@@ -1,11 +1,9 @@
-"""
-SatNOGS Config module initialization
-"""
+"""SatNOGS Config module initialization"""
 import sys
 
 import pkg_resources
 
-import satnogsconfig.settings as settings
+from satnogsconfig import settings
 from satnogsconfig.config import Config
 from satnogsconfig.menu import Menu
 
@@ -19,9 +17,7 @@ MENU_FILE = 'menu.yml'
 
 
 def main():
-    """
-    SatNOGS Setup utility
-    """
+    """SatNOGS Setup utility"""
 
     config = Config(settings.CONFIG_FILE)
     menu = Menu(pkg_resources.resource_stream(__name__, MENU_FILE), config)
